==> selenium-devtools-v117-4.14.1-sources.jar: org/openqa/selenium/devtools/v117/console/Console.java <==
package org.openqa.selenium.devtools.v117.console;

import org.openqa.selenium.Beta;
import org.openqa.selenium.devtools.Command;
import org.openqa.selenium.devtools.Event;
import org.openqa.selenium.devtools.ConverterFunctions;
import com.google.common.collect.ImmutableMap;
import org.openqa.selenium.json.JsonInput;

/**
 * This domain is deprecated - use Runtime or Log instead.
 */
@Deprecated()
public class Console {

    /**
     * Does nothing.
     */
    public static Command<Void> clearMessages() {
        ImmutableMap.Builder<String, Object> params = ImmutableMap.builder();
        return new Command<>("Console.clearMessages", params.build());
    }

    /**
     * Disables console domain, prevents further console messages from being reported to the client.
     */
    public static Command<Void> disable() {
        ImmutableMap.Builder<String, Object> params = ImmutableMap.builder();
        return new Command<>("Console.disable", params.build());
    }

    /**
     * Enables console domain, sends the messages collected so far to the client by means of the
     * `messageAdded` notification.
     */
    public static Command<Void> enable() {
        ImmutableMap.Builder<String, Object> params = ImmutableMap.builder();
        return new Command<>("Console.enable", params.build());
    }

    public static Event<org.openqa.selenium.devtools.v117.console.model.ConsoleMessage> messageAdded() {
        return new Event<>("Console.messageAdded", ConverterFunctions.map("message", org.openqa.selenium.devtools.v117.console.model.ConsoleMessage.class));
    }
}

==> selenium-devtools-v117-4.15.0-sources.jar: org/openqa/selenium/devtools/v117/console/Console.java <==
package org.openqa.selenium.devtools.v117.console;

import org.openqa.selenium.Beta;
import org.openqa.selenium.devtools.Command;
import org.openqa.selenium.devtools.Event;
import org.openqa.selenium.devtools.ConverterFunctions;
import java.util.Map;
import java.util.LinkedHashMap;
import org.openqa.selenium.json.JsonInput;

/**
 * This domain is deprecated - use Runtime or Log instead.
 */
@Deprecated()
public class Console {

    /**
     * Does nothing.
     */
    public static Command<Void> clearMessages() {
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        return new Command<>("Console.clearMessages", Map.copyOf(params));
    }

    /**
     * Disables console domain, prevents further console messages from being reported to the client.
     */
    public static Command<Void> disable() {
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        return new Command<>("Console.disable", Map.copyOf(params));
    }

    /**
     * Enables console domain, sends the messages collected so far to the client by means of the
     * `messageAdded` notification.
     */
    public static Command<Void> enable() {
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        return new Command<>("Console.enable", Map.copyOf(params));
    }

    public static Event<org.openqa.selenium.devtools.v117.console.model.ConsoleMessage> messageAdded() {
        return new Event<>("Console.messageAdded", ConverterFunctions.map("message", org.openqa.selenium.devtools.v117.console.model.ConsoleMessage.class));
    }
}
